@@ -1,5 +1,6 @@
-#!/usr/bin/env python
-# cluster.py - http://www.graphviz.org/content/cluster
+#!/usr/bin/env python3
+
+"""https://graphviz.org/Gallery/directed/cluster.html"""
 
 from graphviz import Digraph
 
